@@ -347,7 +347,7 @@ class AbstractValidator[T](IValidator[T]):
     @overload
     def when(self, predicate: Callable[[T], bool]) -> IConditionBuilder: ...
     @overload
-    def when(self, predicate: Callable[[T], bool], action: Callable[..., None]) -> IConditionBuilder: ...
+    def when(self, predicate: Callable[[T], bool], action: Callable[[], None]) -> IConditionBuilder: ...
     @override
     def when(self, predicate, action) -> IConditionBuilder:
         """Defines a condition that applies to several rules.
@@ -367,7 +367,7 @@ class AbstractValidator[T](IValidator[T]):
     @overload
     def unless(self, predicate: Callable[[T], bool]) -> IConditionBuilder: ...
     @overload
-    def unless(self, predicate: Callable[[T], bool], action: Callable[..., None]) -> IConditionBuilder: ...
+    def unless(self, predicate: Callable[[T], bool], action: Callable[[], None]) -> IConditionBuilder: ...
     @override
     def unless(self, predicate, action) -> IConditionBuilder:
         """Defines an inverse condition that applies to several rules.
